ParallelExtend

Trait ParallelExtend 

pub trait ParallelExtend<T>: Send {
    // Required method
    fn par_extend<I>(&mut self, par_iter: I)
       where I: ParallelIterator<Item = T>;
}
Trait for collections that can be extended in parallel.

Required Methods

fn par_extend<I>(&mut self, par_iter: I)
where I: ParallelIterator<Item = T>,

Extend the collection with items from a parallel iterator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Send + Sync> ParallelExtend<T> for Vec<T>

Source

fn par_extend<I>(&mut self, par_iter: I)
where I: ParallelIterator<Item = T>,

Implementors